==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeVdbAndPocInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeVdbAndPocInfoResponse extends AbstractModel {

    /**
    * 病毒库更新时间。
    */
    @SerializedName("VdbUpdateTime")
    @Expose
    private String VdbUpdateTime;

    /**
    * 漏洞库更新时间。
    */
    @SerializedName("PocUpdateTime")
    @Expose
    private String PocUpdateTime;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 病毒库更新时间。 
     * @return VdbUpdateTime 病毒库更新时间。
     */
    public String getVdbUpdateTime() {
        return this.VdbUpdateTime;
    }

    /**
     * Set 病毒库更新时间。
     * @param VdbUpdateTime 病毒库更新时间。
     */
    public void setVdbUpdateTime(String VdbUpdateTime) {
        this.VdbUpdateTime = VdbUpdateTime;
    }

    /**
     * Get 漏洞库更新时间。 
     * @return PocUpdateTime 漏洞库更新时间。
     */
    public String getPocUpdateTime() {
        return this.PocUpdateTime;
    }

    /**
     * Set 漏洞库更新时间。
     * @param PocUpdateTime 漏洞库更新时间。
     */
    public void setPocUpdateTime(String PocUpdateTime) {
        this.PocUpdateTime = PocUpdateTime;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeVdbAndPocInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeVdbAndPocInfoResponse(DescribeVdbAndPocInfoResponse source) {
        if (source.VdbUpdateTime != null) {
            this.VdbUpdateTime = new String(source.VdbUpdateTime);
        }
        if (source.PocUpdateTime != null) {
            this.PocUpdateTime = new String(source.PocUpdateTime);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "VdbUpdateTime", this.VdbUpdateTime);
        this.setParamSimple(map, prefix + "PocUpdateTime", this.PocUpdateTime);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeVdbAndPocInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeVdbAndPocInfoResponse extends AbstractModel {

    /**
    * 病毒库更新时间。
    */
    @SerializedName("VdbUpdateTime")
    @Expose
    private String VdbUpdateTime;

    /**
    * 漏洞库更新时间。
    */
    @SerializedName("PocUpdateTime")
    @Expose
    private String PocUpdateTime;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 病毒库更新时间。 
     * @return VdbUpdateTime 病毒库更新时间。
     */
    public String getVdbUpdateTime() {
        return this.VdbUpdateTime;
    }

    /**
     * Set 病毒库更新时间。
     * @param VdbUpdateTime 病毒库更新时间。
     */
    public void setVdbUpdateTime(String VdbUpdateTime) {
        this.VdbUpdateTime = VdbUpdateTime;
    }

    /**
     * Get 漏洞库更新时间。 
     * @return PocUpdateTime 漏洞库更新时间。
     */
    public String getPocUpdateTime() {
        return this.PocUpdateTime;
    }

    /**
     * Set 漏洞库更新时间。
     * @param PocUpdateTime 漏洞库更新时间。
     */
    public void setPocUpdateTime(String PocUpdateTime) {
        this.PocUpdateTime = PocUpdateTime;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeVdbAndPocInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeVdbAndPocInfoResponse(DescribeVdbAndPocInfoResponse source) {
        if (source.VdbUpdateTime != null) {
            this.VdbUpdateTime = new String(source.VdbUpdateTime);
        }
        if (source.PocUpdateTime != null) {
            this.PocUpdateTime = new String(source.PocUpdateTime);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "VdbUpdateTime", this.VdbUpdateTime);
        this.setParamSimple(map, prefix + "PocUpdateTime", this.PocUpdateTime);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
